@@ -1,18 +1,21 @@
 #ifndef KOAGENDA_H
 #define KOAGENDA_H
-// $Id: koagenda.h,v 1.12 2001/01/02 22:50:57 cschumac Exp $
+// $Id: koagenda.h,v 1.14 2001/04/18 23:28:57 cschumac Exp $
 
 #include <qscrollview.h>
 #include <qtimer.h>
 #include <qarray.h>
 
+#include <event.h>
+
 #include "koagendaitem.h"
 
 class QPopupMenu;
 class QTime;
-class KOEvent;
 class KConfig;
 
+using namespace KCal;
+
 class KOAgenda : public QScrollView
 {
     Q_OBJECT
@@ -23,7 +26,7 @@ class KOAgenda : public QScrollView
                const char * name=0, WFlags f=0 );
     virtual ~KOAgenda();
 
-    KOEvent *selectedEvent();
+    Event *selectedEvent();
 
     virtual bool eventFilter ( QObject *, QEvent * );   
 
@@ -35,9 +38,9 @@ class KOAgenda : public QScrollView
 
     void setStartHour(int startHour);
 
-    KOAgendaItem *insertItem (KOEvent *event,int X,int YTop,int YBottom);
-    KOAgendaItem *insertAllDayItem (KOEvent *event,int XBegin,int XEnd);
-    void insertMultiItem (KOEvent *event,int XBegin,int XEnd,
+    KOAgendaItem *insertItem (Event *event,int X,int YTop,int YBottom);
+    KOAgendaItem *insertAllDayItem (Event *event,int XBegin,int XEnd);
+    void insertMultiItem (Event *event,int XBegin,int XEnd,
                           int YTop,int YBottom);
 
     void changeColumns(int columns);
@@ -79,19 +82,19 @@ class KOAgenda : public QScrollView
   signals:
     void newEventSignal();
     void newEventSignal(int gx,int gy);
-    void editEventSignal(KOEvent *event);
-    void showEventSignal(KOEvent *event);
-    void deleteEventSignal(KOEvent *event);
+    void editEventSignal(Event *event);
+    void showEventSignal(Event *event);
+    void deleteEventSignal(Event *event);
 
     void itemModified(KOAgendaItem *item);
     void itemSelected(bool);
 
-    void showEventPopupSignal(KOEvent *);
+    void showEventPopupSignal(Event *);
 
     void lowerYChanged(int);
     void upperYChanged(int);
 
-    void startDragSignal(KOEvent *);
+    void startDragSignal(Event *);
 
   protected:
     void drawContents(QPainter *p,int cx, int cy, int cw, int ch);        
