@@ -1,13 +1,15 @@
 #ifndef KOEVENTPOPUPMENU_H
 #define KOEVENTPOPUPMENU_H
-// $Id: koeventpopupmenu.h,v 1.1 2000/07/29 21:18:58 cschumac Exp $
+// $Id: koeventpopupmenu.h,v 1.3 2001/04/18 23:28:57 cschumac Exp $
 //
 // Context menu for event views with standard event actions
 //
 
 #include <qpopupmenu.h>
 
-class KOEvent;
+#include <event.h>
+
+using namespace KCal;
 
 class KOEventPopupMenu : public QPopupMenu {
     Q_OBJECT
@@ -20,7 +22,7 @@ class KOEventPopupMenu : public QPopupMenu {
 
 
   public slots:
-    void showEventPopup(KOEvent *);
+    void showEventPopup(Event *);
 
   protected slots:
     void popupShow();
@@ -28,12 +30,12 @@ class KOEventPopupMenu : public QPopupMenu {
     void popupDelete();
 
   signals:
-    void editEventSignal(KOEvent *);
-    void showEventSignal(KOEvent *);
-    void deleteEventSignal(KOEvent *);
+    void editEventSignal(Event *);
+    void showEventSignal(Event *);
+    void deleteEventSignal(Event *);
     
   private:
-    KOEvent *mCurrentEvent;
+    Event *mCurrentEvent;
     
     bool mHasAdditionalItems;
     QValueList<int> mEditOnlyItems;
